@@ -89,8 +89,8 @@ def scan_volumes(volumes):
 @click.command()
 @click.option('--config-file',  'configfile', type=click.File(), help='Configuration file path', envvar='CONFIG_FILE', show_default=True,
               default=f"{os.path.dirname(os.path.realpath(__file__))}/config.yml")
-@click.option('--force-scan', 'force_scan', flag_value='force_scan', default=True, help='Force scanning of the archive')
-def cli(configfile):
+@click.option('--force-scan', flag_value=True, default=False, help='Force scanning of the archive')
+def cli(configfile, force_scan):
     """
     Command line interface. Stands as main
     """
@@ -117,14 +117,14 @@ def cli(configfile):
                                 host=cfg['postgres']['host'], password=cfg['postgres']['password'], port=cfg['postgres']['port'])
         cur = conn.cursor()
         cur.execute('select distinct date from dataholdings order by date desc limit 1;')
-        last_stat_date = datetime.strptime(cur.fetchone()[0], '%Y-%m-%d')
+        last_stat_date = cur.fetchone()[0]
         conn.close()
-        if today - last_stat_date > timedelta(days=(cfg['cache_ttl'])):
+        if date.today() - last_stat_date > timedelta(days=(cfg['cache_ttl'])):
             logger.info("Cache is old, let's scan volumes")
         else:
             logger.info(
                 "Last data report made at %s. Younger than %s. Don't scan",
-                previous_run_date, cfg['cache_ttl'])
+                last_stat_date, cfg['cache_ttl'])
             sys.exit(0)
 
     statistics = scan_volumes(cfg['volumes'])
